@@ -1,9 +1,13 @@
 from typing import List
 
-from evaluation_metric.cluster_imbalance import measure_cluster_imbalance
-from evaluation_metric.getAgreementRateMetric import GetAgreementRateMetric
-from evaluation_metric.getClusterDiameter import GetClusterDiameter
-from evaluation_metric.getClusteringCost import GetClusteringCost
+from graph_partition.evaluation_metric.cluster_imbalance import (
+    measure_cluster_imbalance,
+)
+from graph_partition.evaluation_metric.getAgreementRateMetric import (
+    GetAgreementRateMetric,
+)
+from graph_partition.evaluation_metric.getClusterDiameter import GetClusterDiameter
+from graph_partition.evaluation_metric.getClusteringCost import GetClusteringCost
 
 
 def evaluate_clustering_metrics(cost_matrix: List[List], class_label: List):
@@ -14,7 +18,7 @@ def evaluate_clustering_metrics(cost_matrix: List[List], class_label: List):
     _min_cluster, _max_cluster, _cif = measure_cluster_imbalance(class_label)
     _evaluation_metrics = {
         "cost": round(_actual_cost.cost, 4),
-        "ARM": _arm.ARM,
+        "ARM": round(_arm.ARM, 4),
         "Cluster Diameters": _dia.cluster_diameters,
         "Cluster Imbalance Factor": round(_cif, 4),
         "Min Cluster Size": _min_cluster,
